diff lisp/emacs-lisp/cl-loaddefs.el @ 107496:893b1b725ad5

Close bug#4427. * emacs-lisp/cl-macs.el (defsubst*): Add autoload cookie. (Bug#4427) * emacs-lisp/cl-loaddefs.el: Regenerate.
author Glenn Morris <rgm@gnu.org>
date Thu, 11 Mar 2010 19:19:17 -0800
parents f364eaefe2b4
children 9c5ceea9a88b 4369f3a9c1de
line wrap: on
line diff
--- a/lisp/emacs-lisp/cl-loaddefs.el	Thu Mar 11 08:25:46 2010 -0800
+++ b/lisp/emacs-lisp/cl-loaddefs.el	Thu Mar 11 19:19:17 2010 -0800
@@ -273,8 +273,8 @@
 
 ;;;***
 
 ;;;### (autoloads (compiler-macroexpand define-compiler-macro assert
 ;;;;;;  check-type typep deftype cl-struct-setf-expander defstruct
 ;;;;;;  define-modify-macro callf2 callf letf* letf rotatef shiftf
 ;;;;;;  remf cl-do-pop psetf setf get-setf-method defsetf define-setf-method
 ;;;;;;  declare the locally multiple-value-setq multiple-value-bind
@@ -282,7 +282,7 @@
 ;;;;;;  flet progv psetq do-all-symbols do-symbols dotimes dolist
 ;;;;;;  do* do loop return-from return block etypecase typecase ecase
 ;;;;;;  case load-time-value eval-when destructuring-bind function*
-;;;;;;  defmacro* defun* gentemp gensym) "cl-macs" "cl-macs.el" "e10a7e42199c08dc39460f67dd2d424b")
+;;;;;;  defmacro* defun* gentemp gensym) "cl-macs" "cl-macs.el" "273ba25f4a116c61a464dbe55f1f8c63")
 ;;; Generated autoloads from cl-macs.el
 
 (autoload 'gensym "cl-macs" "\
@@ -739,6 +739,14 @@
 
 \(fn FORM)" nil nil)
 
+(autoload 'defsubst* "cl-macs" "\
+Define NAME as a function.
+Like `defun', except the function is automatically declared `inline',
+ARGLIST allows full Common Lisp conventions, and BODY is implicitly
+surrounded by (block NAME ...).
+
+\(fn NAME ARGLIST [DOCSTRING] BODY...)" nil (quote macro))
+
 ;;;***
 
 ;;;### (autoloads (tree-equal nsublis sublis nsubst-if-not nsubst-if
@@ -273,8 +273,8 @@
 ;;;***
 
-;;;### (autoloads (compiler-macroexpand define-compiler-macro assert
-;;;;;;  check-type typep deftype cl-struct-setf-expander defstruct
+;;;### (autoloads (defsubst* compiler-macroexpand define-compiler-macro
+;;;;;;  assert check-type typep deftype cl-struct-setf-expander defstruct
 ;;;;;;  define-modify-macro callf2 callf letf* letf rotatef shiftf
 ;;;;;;  remf cl-do-pop psetf setf get-setf-method defsetf define-setf-method